.. _core:

Core
====

Core modules provide internal functionality for `ablate`, such as (grouped) run types.

Types
-----

Types define the basic data structures used throughout `ablate`.

.. autoclass:: ablate.core.types.Run
   :members:
   :exclude-members: model_config

.. autoclass:: ablate.core.types.GroupedRun
   :members:
   :exclude-members: model_config

